@@ -10,20 +10,26 @@ fn it_implements_uniques() {
 
 #[test]
 fn it_implements_individual_uniq_on_vec() {
-  use array_tool::Uniq;
+  use array_tool::vec::Uniq;
   assert_eq!(vec![1,2,3,4,5,6].uniq(vec![1,2,5,7,9]),vec![3,4,6]);
 }
 
 #[test]
 fn it_can_return_its_own_unique(){
-  use array_tool::Uniq;
+  use array_tool::vec::Uniq;
   assert_eq!(vec![1,2,1,3,4,3,4,5,6].unique(),vec![1,2,3,4,5,6]);
 }
 
+#[test]
+fn it_answers_about_uniqueness(){
+  use array_tool::vec::Uniq;
+  assert_eq!(vec![1,2,1,3,4,3,4,5,6].is_unique(), false);
+  assert_eq!(vec![1,2,3,4,5,6].is_unique(), true);
+}
 
 #[test]
 fn it_checks_emptiness(){
-  use array_tool::Empty;
+  use array_tool::vec::Empty;
   let mut x = vec![1];
   assert_eq!(x.empty(), false);
   x.pop();
